"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var convert_bash_1 = require("./convert-bash");
describe('convert-bash', function () {
    describe('convertBashToWin', function () {
        test('should do simple complete conversion', function () {
            expect(convert_bash_1.convertBashToWin('#!/bin/bash\n' +
                '\n' +
                'SOME_VAR="/c/cygwin/path"\n' +
                'rm -rf $SOME_VAR')).toEqual('@echo off\n' +
                '\n' +
                'SET "SOME_VAR=c:\\cygwin\\path"\n' +
                'DEL /S "%SOME_VAR%"');
        });
        test('should handle simple full line comment', function () {
            expect(convert_bash_1.convertBashToWin('echo "hi"\n# this is a comment'))
                .toEqual('@echo off\necho "hi"\nREM this is a comment');
        });
        test('should preserve empty lines', function () {
            expect(convert_bash_1.convertBashToWin('echo "hi"\n\n\n# this is a comment'))
                .toEqual('@echo off\necho "hi"\n\n\nREM this is a comment');
        });
        test('should transform single command', function () {
            expect(convert_bash_1.convertBashToWin('rm -rf /c/cygwin/path'))
                .toEqual('@echo off\nDEL /S "c:\\cygwin\\path"');
        });
        test('should handle "&&"', function () {
            expect(convert_bash_1.convertBashToWin('echo "hi 1" && echo "there 2"'))
                .toEqual('@echo off\necho "hi 1" && echo "there 2"');
        });
        describe('convertPaths', function () {
            test('should convert win path', function () {
                expect(convert_bash_1.convertBashToWin('mycommand /absolutepath'))
                    .toEqual('@echo off\nmycommand "\\absolutepath"');
            });
            test('should convert cyg win path', function () {
                expect(convert_bash_1.convertBashToWin('mycommand /c/cygwin/path'))
                    .toEqual('@echo off\nmycommand "c:\\cygwin\\path"');
            });
            test('should convert relative path', function () {
                expect(convert_bash_1.convertBashToWin('mycommand path/sub'))
                    .toEqual('@echo off\nmycommand "path\\sub"');
            });
            test('should convert relative path current dir', function () {
                expect(convert_bash_1.convertBashToWin('mycommand ./path'))
                    .toEqual('@echo off\nmycommand "%CD%\\path"');
            });
            test('should convert relative path parent dir', function () {
                expect(convert_bash_1.convertBashToWin('mycommand ../path'))
                    .toEqual('@echo off\nmycommand "%CD%\\..\\path"');
            });
            test('should keep cd to parent dir', function () {
                expect(convert_bash_1.convertBashToWin('cd ..'))
                    .toEqual('@echo off\ncd ".."');
            });
            test('should convert file with extension', function () {
                expect(convert_bash_1.convertBashToWin('mycommand path/file.txt'))
                    .toEqual('@echo off\nmycommand "path\\file.txt"');
            });
            test('should handle simple url', function () {
                expect(convert_bash_1.convertBashToWin('wget https://website.com'))
                    .toEqual('@echo off\nwget "https://website.com"');
            });
            test('should handle url with query', function () {
                expect(convert_bash_1.convertBashToWin('wget https://website.com/path?query=1'))
                    .toEqual('@echo off\nwget "https://website.com/path?query=1"');
            });
        });
        test('should handle "||"', function () {
            expect(convert_bash_1.convertBashToWin('echo "hi 1" || echo "there 2"'))
                .toEqual('@echo off\necho "hi 1" || echo "there 2"');
        });
        test('should handle simple if', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" == "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" == "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle if-else', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" == "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                'else\n' +
                '  echo "my_var is not empty"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" == "" (\n  echo "my_var is empty"\n) ELSE (\n  echo "my_var is not empty"\n)');
        });
        test('should handle simple if -eq', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" -eq "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" EQU "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle simple if -ne', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" -ne "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" NEQ "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle simple if -lt', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" -lt "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" LSS "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle simple if -le', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" -le "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" LEQ "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle simple if -gt', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" -gt "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" GTR "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle simple if -ge', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" -ge "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF "%my_var%" GEQ "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle simple if not equal', function () {
            expect(convert_bash_1.convertBashToWin('if [ ! "$my_var" == "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\nIF NOT "%my_var%" == "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle string interpolation with backticks', function () {
            expect(convert_bash_1.convertBashToWin('my_var="test-`git log`"'))
                .toEqual('@echo off\n' +
                'setlocal EnableDelayedExpansion\n' +
                'SET _INTERPOLATION_0=\n' +
                'FOR /f "delims=" %%a in (\'git log\') DO (SET "_INTERPOLATION_0=!_INTERPOLATION_0! %%a")\n' +
                'SET "my_var=test-!_INTERPOLATION_0:~1!"');
        });
        test('should echo variable correctly with delayed expansion', function () {
            expect(convert_bash_1.convertBashToWin('my_var="test-`git log`"\necho $my_var'))
                .toEqual('@echo off\n' +
                'setlocal EnableDelayedExpansion\n' +
                'SET _INTERPOLATION_0=\n' +
                'FOR /f "delims=" %%a in (\'git log\') DO (SET "_INTERPOLATION_0=!_INTERPOLATION_0! %%a")\n' +
                'SET "my_var=test-!_INTERPOLATION_0:~1!"\n' +
                'echo "!my_var!"');
        });
        test('should activate delayed expansion for interpolation in function', function () {
            expect(convert_bash_1.convertBashToWin("function my_function () {\n  my_var=\"test-$(git log)\"\n  echo \"hello from my_function: $my_var\"\n}"))
                .toEqual("@echo off\nsetlocal EnableDelayedExpansion\n\n\nEXIT /B %ERRORLEVEL%\n\n:my_function\nSET _INTERPOLATION_0=\nFOR /f \"delims=\" %%a in ('git log') DO (SET \"_INTERPOLATION_0=!_INTERPOLATION_0! %%a\")\nSET \"my_var=test-!_INTERPOLATION_0:~1!\"\necho \"hello from my_function: !my_var!\"\nEXIT /B 0\n");
        });
        test('should handle string interpolation with dollar brackets', function () {
            expect(convert_bash_1.convertBashToWin('my_var="test-$(git log)"'))
                .toEqual('@echo off\n' +
                'setlocal EnableDelayedExpansion\n' +
                'SET _INTERPOLATION_0=\n' +
                'FOR /f "delims=" %%a in (\'git log\') DO (SET "_INTERPOLATION_0=!_INTERPOLATION_0! %%a")\n' +
                'SET "my_var=test-!_INTERPOLATION_0:~1!"');
        });
        test('should handle switch case', function () {
            expect(convert_bash_1.convertBashToWin('case "$1" in\n' +
                '  "Darwin")\n' +
                '    echo "found darwin"\n' +
                '    ;;\n' +
                '  "Jesus")\n' +
                '    echo "found jesus"\n' +
                '    ;;\n' +
                '  *)\n' +
                '    echo "not found darwin nor jesus"\n' +
                '    ;;\n' +
                'esac'))
                .toEqual('@echo off\n' +
                'IF "%~1"=="Darwin" (\n' +
                '  echo "found darwin"\n' +
                ') ELSE IF "%~1"=="Jesus" (\n' +
                '  echo "found jesus"\n' +
                ') ELSE (\n' +
                '  echo "not found darwin nor jesus"\n' +
                ')');
        });
        test('should handle function declaration with comment', function () {
            expect(convert_bash_1.convertBashToWin("function my_function () {\n  # this is a comment\n  echo \"hello from my_function: $1\"\n}"))
                .toEqual("@echo off\n\n\nEXIT /B %ERRORLEVEL%\n\n:my_function\nREM this is a comment\necho \"hello from my_function: %~1\"\nEXIT /B 0\n");
        });
        test('should handle function declaration with keyword at start', function () {
            expect(convert_bash_1.convertBashToWin("function my_function () {\n  echo \"hello from my_function: $1\"\n}"))
                .toEqual("@echo off\n\n\nEXIT /B %ERRORLEVEL%\n\n:my_function\necho \"hello from my_function: %~1\"\nEXIT /B 0\n");
        });
        test('should handle function declaration with keyword in middle', function () {
            expect(convert_bash_1.convertBashToWin("echo \"test\"\n            function my_function () {\n  echo \"hello from my_function: $1\"\n}"))
                .toEqual("@echo off\necho \"test\"\n\nEXIT /B %ERRORLEVEL%\n\n:my_function\necho \"hello from my_function: %~1\"\nEXIT /B 0\n");
        });
        test('should transform complete example', function () {
            expect(convert_bash_1.convertBashToWin("#!/bin/bash\n\nSOME_VAR=\"/c/cygwin/path\"\nrm -rf $SOME_VAR\ncp /c/some/file /to/another/file\n\nmy_function () {\n  echo \"hello from my_function: $1\"\n}\n# call the function:\nmy_function\n# call the function with param:\nmy_function \"some param\"\n")).toEqual("@echo off\n\nSET \"SOME_VAR=c:\\cygwin\\path\"\nDEL /S \"%SOME_VAR%\"\nCOPY  \"c:\\some\\file\" \"\\to\\another\\file\"\n\nREM call the function:\nCALL :my_function\nREM call the function with param:\nCALL :my_function \"some param\"\n\nEXIT /B %ERRORLEVEL%\n\n:my_function\necho \"hello from my_function: %~1\"\nEXIT /B 0\n");
        });
    });
});
